@@ -79,6 +79,7 @@ class Azure:
         # check for configuration file
         if not isfile(config_fname):
             self.client = None
+            self._container = None
             if check:
                 self._check_connection()
             else:
@@ -189,12 +190,12 @@ class Azure:
             If :code:`file` does not exist in Azure
         """
 
-        # get container
-        container = self._get_container(container)
-
         # process regular expresion
         if regex:
 
+            # get container
+            container = self._get_container(container)
+
             # download each file that matches pattern
             [
                 self.download(
@@ -214,6 +215,9 @@ class Azure:
         if not replace and isfile(file):
             return
 
+        # get container
+        container = self._get_container(container)
+
         # check connection
         self._check_connection()
 
@@ -322,8 +326,11 @@ class Azure:
                 return
 
         # check if is html file
-        if basename(file).rsplit('.')[-1] == 'html':
+        ext = basename(file).rsplit('.')[-1]
+        if ext == 'html':
             content_settings = ContentSettings(content_type='text/html')
+        elif ext == 'css':
+            content_settings = ContentSettings(content_type='text/css')
         else:
             content_settings = None
 
